# 协作者与维护者

作为该语言的资深用户、该软件的专家、镜像站维护人员等，你总是对镜像站和源的可用状态拥有一手信息，我们需要你的帮助。如果想要达到最理想的维护状态，每一个 recipe 都需要有专人长时间维护。所以我们在这个文件记录的是愿意**长期**维护的人，如果是一次性提交代码，只需要在对应 recipe 的文件标头中记录即可。

**我们的代码里使用了 recipe (某个菜的烹饪方法) 这个词，因而整个项目便和 “吃” 有关，比如 `menu`: 汇集了所有的 target 的菜单。因此，我们的维护者身份依然使用了这个惯例：**

一个 recipe 的协作者可分为：

1. **Chef**

    主厨: 对一个 recipe 完全负责，有写权限时可以直接推代码

    **目前项目的发展阶段还处于 *外行实现内行* 的情况，比如 Homebrew recipe，实现者根本不是 Homebrew 的真实用户，只是根据各种文档来实现，然后等待用户反馈。所以这里当前的实现者最多只能是 Sous Chef，无法承担 Chef 的责任**

2. **Sous Chef**

    副主厨：实现和持续维护 recipe，需要和 Chef 一起 review 代码。可参考 [03-CONTRIBUTING.md](./03-CONTRIBUTING.md) 了解项目是如何进行提交和审阅代码的

3. **Taster**

    试吃员：对该 target 和 recipe 持续反馈和关注的用户。如果你觉得你无法承担作为维护者的责任，可以退而求其次作为观察者积极参与其中

<br>

**项目采用申请制，请提交 PULL REQUEST 在该文件中添加自己，并在 [issue #130](https://github.com/RubyMetric/chsrc/issues/130) 留言。考虑到真正参与维护的人并不多，所以上述人数均不设限。**

`@`后面跟的是GitHub账户名，如 `@ccmywish`。若使用Gitee账号，则使用 `@gitee:ccmywish`。对我们来说，镜像站成员非常重要，所以请额外标注身份，如 `@username [TUNA]`

<br>

## Framework

1. **Chef**: `@ccmywish` `@gitee:G_I_Y`
2. **Sous Chef**:
3. **Taster**:

<br>

## 编程语言

### Ruby

1. **Chef**: `@ccmywish`
2. **Sous Chef**:
3. **Taster**:

### Python

1. **Chef**:
2. **Sous Chef**: `@ccmywish` `@happy-game`
3. **Taster**:

### NodeJS

1. **Chef**:
2. **Sous Chef**: `@ccmywish` `@happy-game`
3. **Taster**:

### Perl

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**:

### PHP

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### Go

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### Rust

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### Java

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### Clojure

1. **Chef**:
2. **Sous Chef**:
3. **Taster**:

### NuGet

1. **Chef**:
2. **Sous Chef**:
3. **Taster**:

### Dart

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### Haskell

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### OCaml

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### R

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:  `@gitee:tfcolin`

### Julia

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

<br>

## 操作系统

### Ubuntu

1. **Chef**: `@ccmywish`
2. **Sous Chef**: `@gitee:G_I_Y`
3. **Taster**: `@wickdynex`

### Debian

1. **Chef**:
2. **Sous Chef**: `@ccmywish` `@gitee:G_I_Y`
3. **Taster**: `@happy-game`

### Fedora

1. **Chef**:
2. **Sous Chef**:  `@ccmywish` `@gitee:G_I_Y` `@happy-game`
3. **Taster**:

### Kali

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y`
3. **Taster**:

### Linux Mint

1. **Chef**:
2. **Sous Chef**: `@ccmywish` `@gitee:G_I_Y`
3. **Taster**:

### Armbian

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### Raspberry Pi OS

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### ROS

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y` `@ccmywish`
3. **Taster**:

### Trisquel

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**:

### Arch

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`  `@gitee:G_I_Y` `@happy-game`
3. **Taster**:

### Manjaro

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y` `@ccmywish`
3. **Taster**:

### msys2

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y` `@ccmywish`
3. **Taster**:

### Alpine

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### OpenWrt

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**: `@happy-game`

### Gentoo

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y`
3. **Taster**:

### Void Linux

1. **Chef**:
2. **Sous Chef**:  `@ccmywish`
3. **Taster**:

### deepin

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y`
3. **Taster**:

### OpenKylin

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y`
3. **Taster**:

### OpenEuler

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y`
3. **Taster**:

### FreeBSD

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y` `@ccmywish`
3. **Taster**: `@ykla`

### NetBSD

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y` `@ccmywish`
3. **Taster**:

### OpenBSD

1. **Chef**:
2. **Sous Chef**:  `@gitee:G_I_Y` `@ccmywish`
3. **Taster**:

<br>

## 软件

### Homebrew

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**: `@wickdynex`

### WinGet

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**:

### Flathub

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**:

### Nix

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**:

### Guix

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**:

### CocoaPods

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**:

### Docker Hub

1. **Chef**:
2. **Sous Chef**: `@ccmywish` `@happy-game`
3. **Taster**:

### Anaconda

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**: `@happy-game`

### Emacs

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**:

### Tex Live

1. **Chef**:
2. **Sous Chef**: `@ccmywish`
3. **Taster**:

<br>
